@@ -11,7 +11,7 @@ class DayOffFilter(wb_filters.FilterSet):
         required=True,
         clearable=False,
         method=wb_filters.DateRangeFilter.base_date_range_filter_method,
-        default=current_year_date_range,
+        initial=current_year_date_range,
     )
 
     def start_filter(self, queryset, name, value):
